<?php

	

	require("../lib/smarty.php");
	require("../lib/session_on.php");
		
	$smarty->assign("title","TOP");
	$smarty->assign("pagename","index");
	$smarty->assign("session_status",session_continue("TestCookie"));
	$smarty->display("index.tpl");

	
